==> elucidata-build-tools-1.0.1.tgz: package/lib/elucidata-build-tools/stitch.js <==
(function() {
  var BasePackage, CoffeeScript, CssPackage, Package, async, defaultCompilers, defaultCssCompilers, extname, fs, join, less, normalize, path, _, _ref;
  var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; }, __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  };
  _ = require('underscore');
  async = require('async');
  fs = require('fs');
  _ref = require('path'), extname = _ref.extname, join = _ref.join, normalize = _ref.normalize;
  defaultCompilers = {
    js: function(module, filename) {
      var content;
      content = fs.readFileSync(filename, 'utf8');
      return module._compile(content, filename);
    }
  };
  try {
    CoffeeScript = require('coffee-script');
    defaultCompilers.coffee = function(module, filename) {
      var content;
      content = CoffeeScript.compile(fs.readFileSync(filename, 'utf8'));
      return module._compile(content, filename);
    };
  } catch (err) {

  }
  defaultCssCompilers = {
    css: function(module, filename) {
      var content;
      content = fs.readFileSync(filename, 'utf8');
      return module._compile(content, filename);
    }
  };
  try {
    less = require('less');
    path = require('path');
    defaultCssCompilers.less = function(module, filename) {
      var basepath, content;
      basepath = path.dirname(filename);
      content = fs.readFileSync(filename, 'utf8');
      return less.render(content, {
        paths: [basepath]
      }, function(err, css) {
        if (err != null) {
          throw err;
        }
        return module._compile(css, filename);
      });
    };
  } catch (err) {

  }
  BasePackage = (function() {
    function BasePackage(config) {
      this.identifier = config.identifier || 'require';
      this.paths = config.paths || ['lib'];
      this.compilers = _.extend({}, defaultCompilers, config.compilers);
      this.cache = config.cache || true;
      this.mtimeCache = {};
      this.compileCache = {};
    }
    BasePackage.prototype.compile = function(callback) {
      return async.reduce(this.paths, {}, _.bind(this.gatherSourcesFromPath, this), __bind(function(err, sources) {
        var filename, index, name, result, source, _ref;
        if (err) {
          return callback(err);
        }
        result = "var " + this.identifier + " = (function(modules) {\n  var exportCache = {};\n// for(name in modules) { console.log(name); }\n  return function require(name) {\n    var module = exportCache[name];\n    var fn;\n    if (module) {\n      return module;\n    } else if (fn = modules[name]) {\n      module = { id: name, exports: {} };\n      fn(module.exports, require, module);\n      exportCache[name] = module.exports;\n      return module.exports;\n    } else {\n      throw 'module \\'' + name + '\\' not found';\n    }\n  }\n})({";
        index = 0;
        for (name in sources) {
          _ref = sources[name], filename = _ref.filename, source = _ref.source;
          result += index++ === 0 ? "" : ", ";
          result += JSON.stringify(name);
          result += ": function(exports, require, module) {" + source + "}";
        }
        result += "});\n";
        return callback(err, result);
      }, this));
    };
    BasePackage.prototype.createServer = function() {
      return __bind(function(req, res, next) {
        return this.compile(function(err, source) {
          var message;
          if (err) {
            console.error("" + err.stack);
            message = "" + err.stack;
            res.writeHead(500, {
              'Content-Type': 'text/javascript'
            });
            return res.end("throw " + (JSON.stringify(message)));
          } else {
            res.writeHead(200, {
              'Content-Type': 'text/javascript'
            });
            return res.end(source);
          }
        });
      }, this);
    };
    BasePackage.prototype.gatherSourcesFromPath = function(sources, sourcePath, callback) {
      return fs.stat(sourcePath, __bind(function(err, stat) {
        if (err) {
          return callback(err);
        }
        if (stat.isDirectory()) {
          return this.getFilesInTree(sourcePath, __bind(function(err, paths) {
            if (err) {
              return callback(err);
            }
            return async.reduce(paths, sources, _.bind(this.gatherCompilableSource, this), callback);
          }, this));
        } else {
          return this.gatherCompilableSource(sources, sourcePath, callback);
        }
      }, this));
    };
    BasePackage.prototype.gatherCompilableSource = function(sources, path, callback) {
      if (this.compilers[extname(path).slice(1)]) {
        return this.getRelativePath(path, __bind(function(err, relativePath) {
          if (err) {
            return callback(err);
          }
          return this.compileFile(path, function(err, source) {
            var extension, key;
            if (err) {
              return callback(err);
            } else {
              extension = extname(relativePath);
              key = relativePath.slice(0, -extension.length);
              sources[key] = {
                filename: relativePath,
                source: source
              };
              return callback(err, sources);
            }
          });
        }, this));
      } else {
        return callback(null, sources);
      }
    };
    BasePackage.prototype.getRelativePath = function(path, callback) {
      path = normalize(path);
      return async.map(this.paths, fs.realpath, function(err, expandedPaths) {
        var base, expandedPath, _i, _len;
        if (err) {
          return callback(err);
        }
        for (_i = 0, _len = expandedPaths.length; _i < _len; _i++) {
          expandedPath = expandedPaths[_i];
          base = expandedPath + "/";
          if (path.indexOf(base) === 0) {
            return callback(null, path.slice(base.length));
          }
        }
        return callback("" + path + " isn't in the require path");
      });
    };
    BasePackage.prototype.compileFile = function(path, callback) {
      var compile, err, extension, mod, mtime, source;
      extension = extname(path).slice(1);
      if (this.cache && this.compileCache[path] && this.mtimeCache[path] === this.compileCache[path].mtime) {
        return callback(null, this.compileCache[path].source);
      } else if (compile = this.compilers[extension]) {
        source = null;
        mod = {
          _compile: function(content, filename) {
            return source = content;
          }
        };
        try {
          compile(mod, path);
          if (this.cache && (mtime = this.mtimeCache[path])) {
            this.compileCache[path] = {
              mtime: mtime,
              source: source
            };
          }
          return callback(null, source);
        } catch (err) {
          if (err instanceof Error) {
            err.message = "can't compile " + path + "\n" + err.message;
          } else {
            err = new Error("can't compile " + path + "\n" + err);
          }
          return callback(err);
        }
      } else {
        return callback("no compiler for '." + extension + "' files");
      }
    };
    BasePackage.prototype.walkTree = function(directory, callback) {
      return fs.readdir(directory, __bind(function(err, files) {
        if (err) {
          return callback(err);
        }
        return async.forEach(files, __bind(function(file, next) {
          var filename;
          if (file.match(/^\./)) {
            return next();
          }
          filename = join(directory, file);
          return fs.stat(filename, __bind(function(err, stats) {
            var _ref;
            this.mtimeCache[filename] = stats != null ? (_ref = stats.mtime) != null ? _ref.toString() : void 0 : void 0;
            if (!err && stats.isDirectory()) {
              return this.walkTree(filename, function(err, filename) {
                if (filename) {
                  return callback(err, filename);
                } else {
                  return next();
                }
              });
            } else {
              callback(err, filename);
              return next();
            }
          }, this));
        }, this), callback);
      }, this));
    };
    BasePackage.prototype.getFilesInTree = function(directory, callback) {
      var files;
      files = [];
      return this.walkTree(directory, function(err, filename) {
        if (err) {
          return callback(err);
        } else if (filename) {
          return files.push(filename);
        } else {
          return callback(err, files.sort());
        }
      });
    };
    return BasePackage;
  })();
  exports.Package = Package = (function() {
    function Package() {
      Package.__super__.constructor.apply(this, arguments);
    }
    __extends(Package, BasePackage);
    return Package;
  })();
  exports.CssPackage = CssPackage = (function() {
    __extends(CssPackage, BasePackage);
    function CssPackage(config) {
      CssPackage.__super__.constructor.call(this, config);
      this.compilers = _.extend({}, defaultCssCompilers, config.compilers);
    }
    CssPackage.prototype.compile = function(callback) {
      return async.reduce(this.paths, {}, _.bind(this.gatherSourcesFromPath, this), __bind(function(err, sources) {
        var filename, name, results, source, _ref;
        if (err) {
          return callback(err);
        }
        results = [];
        for (name in sources) {
          _ref = sources[name], filename = _ref.filename, source = _ref.source;
          results.push("/* " + filename + " */\n" + source + "\n");
        }
        return callback(err, results.join("\n"));
      }, this));
    };
    return CssPackage;
  })();
  exports.createPackage = function(config) {
    return new Package(config);
  };
  exports.createCssPackage = function(config) {
    return new CssPackage(config);
  };
}).call(this);

==> elucidata-build-tools-1.0.3.tgz: package/lib/elucidata-build-tools/stitch.js <==
(function() {
  var BasePackage, CoffeeScript, CssPackage, Package, async, defaultCompilers, defaultCssCompilers, dirname, extname, fs, inspect, join, less, normalize, puts, _, _ref, _ref2;
  var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; }, __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  };
  _ = require('underscore');
  async = require('async');
  fs = require('fs');
  _ref = require('path'), dirname = _ref.dirname, extname = _ref.extname, join = _ref.join, normalize = _ref.normalize;
  _ref2 = require('sys'), puts = _ref2.puts, inspect = _ref2.inspect;
  defaultCompilers = {
    js: function(module, filename) {
      var content;
      content = fs.readFileSync(filename, 'utf8');
      return module._compile(content, filename);
    }
  };
  try {
    CoffeeScript = require('coffee-script');
    defaultCompilers.coffee = function(module, filename) {
      var content;
      content = CoffeeScript.compile(fs.readFileSync(filename, 'utf8'));
      return module._compile(content, filename);
    };
  } catch (err) {

  }
  defaultCssCompilers = {
    css: function(module, filename) {
      var content;
      content = fs.readFileSync(filename, 'utf8');
      return module._compile(content, filename);
    }
  };
  try {
    less = require('less');
    defaultCssCompilers.less = function(module, filename) {
      var basepath, content;
      basepath = dirname(filename);
      content = fs.readFileSync(filename, 'utf8');
      return less.render(content, {
        paths: [process.cwd(), basepath]
      }, function(err, css) {
        if (err != null) {
          module._error(err);
        }
        return module._compile(css, filename);
      });
    };
  } catch (err) {

  }
  BasePackage = (function() {
    function BasePackage(config) {
      this.identifier = config.identifier || 'require';
      this.paths = config.paths || ['lib'];
      this.compilers = _.extend({}, defaultCompilers, config.compilers);
      this.cache = config.cache || true;
      this.mtimeCache = {};
      this.compileCache = {};
    }
    BasePackage.prototype.compile = function(callback) {
      return async.reduce(this.paths, {}, _.bind(this.gatherSourcesFromPath, this), __bind(function(err, sources) {
        var filename, index, name, result, source, _ref;
        if (err) {
          return callback(err);
        }
        result = "var " + this.identifier + " = (function(modules) {\n  var exportCache = {};\n// for(name in modules) { console.log(name); }\n  return function " + this.identifier + "(name) {\n    var module = exportCache[name];\n    var fn;\n    if (module) {\n      return module;\n    } else if (fn = modules[name] || modules[name +'/index']) {\n      module = { id: name, exports: {} };\n      fn(module.exports, require, module);\n      exportCache[name] = module.exports;\n      return module.exports;\n    } else {\n      throw 'module \\'' + name + '\\' not found';\n    }\n  }\n})({";
        index = 0;
        for (name in sources) {
          _ref = sources[name], filename = _ref.filename, source = _ref.source;
          result += index++ === 0 ? "" : ", ";
          result += JSON.stringify(name);
          result += ": function(exports, require, module) {" + source + "}";
        }
        result += "});\n";
        return callback(err, result);
      }, this));
    };
    BasePackage.prototype.createServer = function() {
      return __bind(function(req, res, next) {
        return this.compile(function(err, source) {
          var message;
          if (err) {
            console.error("" + err.stack);
            message = "" + err.stack;
            res.writeHead(500, {
              'Content-Type': 'text/javascript'
            });
            return res.end("throw " + (JSON.stringify(message)));
          } else {
            res.writeHead(200, {
              'Content-Type': 'text/javascript'
            });
            return res.end(source);
          }
        });
      }, this);
    };
    BasePackage.prototype.gatherSourcesFromPath = function(sources, sourcePath, callback) {
      return fs.stat(sourcePath, __bind(function(err, stat) {
        if (err) {
          return callback(err);
        }
        if (stat.isDirectory()) {
          return this.getFilesInTree(sourcePath, __bind(function(err, paths) {
            if (err) {
              return callback(err);
            }
            return async.reduce(paths, sources, _.bind(this.gatherCompilableSource, this), callback);
          }, this));
        } else {
          return this.gatherCompilableSource(sources, sourcePath, callback);
        }
      }, this));
    };
    BasePackage.prototype.gatherCompilableSource = function(sources, path, callback) {
      if (this.compilers[extname(path).slice(1)]) {
        return this.getRelativePath(path, __bind(function(err, relativePath) {
          if (err) {
            return callback(err);
          }
          return this.compileFile(path, function(err, source) {
            var extension, key;
            if (err) {
              return callback(err);
            } else {
              extension = extname(relativePath);
              key = relativePath.slice(0, -extension.length);
              sources[key] = {
                filename: relativePath,
                source: source
              };
              return callback(err, sources);
            }
          });
        }, this));
      } else {
        return callback(null, sources);
      }
    };
    BasePackage.prototype.getRelativePath = function(path, callback) {
      path = normalize(path);
      return async.map(this.paths, fs.realpath, function(err, expandedPaths) {
        var base, expandedPath, _i, _len;
        if (err) {
          return callback(err);
        }
        for (_i = 0, _len = expandedPaths.length; _i < _len; _i++) {
          expandedPath = expandedPaths[_i];
          base = expandedPath + "/";
          if (path.indexOf(base) === 0) {
            return callback(null, path.slice(base.length));
          }
        }
        return callback("" + path + " isn't in the require path");
      });
    };
    BasePackage.prototype.compileFile = function(path, callback) {
      var cache, compile, compileCache, err, extension, mod, msg, mtimeCache, source;
      extension = extname(path).slice(1);
      if (this.cache && this.compileCache[path] && this.mtimeCache[path] === this.compileCache[path].mtime) {
        return callback(null, this.compileCache[path].source);
      } else if (compile = this.compilers[extension]) {
        source = null;
        cache = this.cache;
        mtimeCache = this.mtimeCache;
        compileCache = this.compileCache;
        mod = {
          _compile: function(content, filename) {
            var mtime;
            source = content;
            if (cache && (mtime = mtimeCache[path])) {
              compileCache[path] = {
                mtime: mtime,
                source: source
              };
            }
            return callback(null, source);
          },
          _error: function(err) {
            return callback(err);
          }
        };
        try {
          return compile(mod, path);
        } catch (err) {
          if (err instanceof Error) {
            err.message = "can't compile " + path + ":\n" + (err.message || err);
          } else {
            if (err.callExtract != null) {
              msg = "" + err.callLine + ": " + err.callExtract;
              err = new Error("can't compile " + path + ".\n" + msg);
            } else {
              err = new Error("can't compile " + path + ".\n" + (err.message || err));
            }
          }
          return callback(err);
        }
      } else {
        return callback("no compiler for '." + extension + "' files");
      }
    };
    BasePackage.prototype.walkTree = function(directory, callback) {
      return fs.readdir(directory, __bind(function(err, files) {
        if (err) {
          return callback(err);
        }
        return async.forEach(files, __bind(function(file, next) {
          var filename;
          if (file.match(/^\./)) {
            return next();
          }
          filename = join(directory, file);
          return fs.stat(filename, __bind(function(err, stats) {
            var _ref;
            this.mtimeCache[filename] = stats != null ? (_ref = stats.mtime) != null ? _ref.toString() : void 0 : void 0;
            if (!err && stats.isDirectory()) {
              return this.walkTree(filename, function(err, filename) {
                if (filename) {
                  return callback(err, filename);
                } else {
                  return next();
                }
              });
            } else {
              callback(err, filename);
              return next();
            }
          }, this));
        }, this), callback);
      }, this));
    };
    BasePackage.prototype.getFilesInTree = function(directory, callback) {
      var files;
      files = [];
      return this.walkTree(directory, function(err, filename) {
        if (err) {
          return callback(err);
        } else if (filename) {
          return files.push(filename);
        } else {
          return callback(err, files.sort());
        }
      });
    };
    return BasePackage;
  })();
  exports.Package = Package = (function() {
    function Package() {
      Package.__super__.constructor.apply(this, arguments);
    }
    __extends(Package, BasePackage);
    return Package;
  })();
  exports.CssPackage = CssPackage = (function() {
    __extends(CssPackage, BasePackage);
    function CssPackage(config) {
      CssPackage.__super__.constructor.call(this, config);
      this.compilers = _.extend({}, defaultCssCompilers, config.compilers);
    }
    CssPackage.prototype.compile = function(callback) {
      return async.reduce(this.paths, {}, _.bind(this.gatherSourcesFromPath, this), __bind(function(err, sources) {
        var filename, name, results, source, _ref;
        if (err) {
          return callback(err);
        }
        results = [];
        for (name in sources) {
          _ref = sources[name], filename = _ref.filename, source = _ref.source;
          results.push("/* " + filename + " */\n" + source + "\n");
        }
        return callback(err, results.join("\n"));
      }, this));
    };
    return CssPackage;
  })();
  exports.createPackage = function(config) {
    return new Package(config);
  };
  exports.createCssPackage = function(config) {
    return new CssPackage(config);
  };
}).call(this);
